==> scm_0.5.9-1.tar.gz: src/opt/shortcutmkr/main.py <==
#!/usr/bin/python2.5
import sys
import os
from PyQt4 import QtGui,QtCore
from shortcutmkr import *
contact = ('')
num = ('')
class MyForm(QtGui.QMainWindow):
	def __init__(self, parent=None):
		#build parent user interface
		QtGui.QWidget.__init__(self, parent)
		self.ui = Ui_ShortcutMaker()
		self.ui.setupUi(self)

		#connect buttons
		QtCore.QObject.connect(self.ui.pushButton_3, QtCore.SIGNAL('clicked()'), self.doSms)
		QtCore.QObject.connect(self.ui.pushButton_4, QtCore.SIGNAL('clicked()'), self.doEmail)
		QtCore.QObject.connect(self.ui.pushButton_5, QtCore.SIGNAL('clicked()'), self.doPhone)
		QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.doDeletesms)
		QtCore.QObject.connect(self.ui.pushButton_2, QtCore.SIGNAL('clicked()'), self.doDeleteemail)
		QtCore.QObject.connect(self.ui.pushButton_6, QtCore.SIGNAL('clicked()'), self.doDeletephone)

		#Create Sub's
	def doDeletesms(self): 
		contact = self.ui.lineEdit.text()
		os.remove('/usr/share/applications/hildon/sms'+contact+'.desktop')
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')
	
	def doDeleteemail(self):
		contact = self.ui.lineEdit.text()
		os.remove('/usr/share/applications/hildon/email'+contact+'.desktop')
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')

	def doDeletephone(self):
		contact = self.ui.lineEdit.text()
		os.remove('/usr/share/applications/hildon/phone'+contact+'.desktop')
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')

	def doSms(self):
		contact  = self.ui.lineEdit.text()
		num = self.ui.lineEdit_2.text()
		fsock = open('/usr/share/applications/hildon/sms'+ contact +'.desktop', 'w') 

		saveout = sys.stdout                                     
                            

		sys.stdout = fsock                                       

		print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=SMS to''', contact,'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","EnsureChannel","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"''',num,'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.Text"},0,""))'
Icon=general_sms''', 

		sys.stdout = saveout                                     

		fsock.close()
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')
	
	def doEmail(self):
		contact  = self.ui.lineEdit.text()
		num = self.ui.lineEdit_2.text()
		fsock2 = open('/usr/share/applications/hildon/email'+ contact +'.desktop', 'w') 

		saveout = sys.stdout                                     
                            

		sys.stdout = fsock2                                       

		print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=EMAIL to ''',contact,'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("com.nokia.modest","/com/nokia/modest", "com.nokia.modest","ComposeMail","ssssss", ("''',num,'''","","","SUBJECT","BODY",""))'
Icon=general_email'''

		sys.stdout = saveout                                     

		fsock2.close()
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')

	def doPhone(self):
		contact  = self.ui.lineEdit.text()
		num = self.ui.lineEdit_2.text()
		fsock3 = open('/usr/share/applications/hildon/phone'+ contact +'.desktop', 'w') 

		saveout = sys.stdout                                     
                            

		sys.stdout = fsock3                                       

		print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=Call ''',contact,'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","Create","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"''',num,'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.StreamedMedia"},0,""))'
Icon=general_call'''

		sys.stdout = saveout                                     

		fsock3.close()
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')
		


if __name__ == "__main__":
	app = QtGui.QApplication(sys.argv)
	myapp = MyForm()
	myapp.show()
	sys.exit(app.exec_())

==> scm_0.6.0-3.tar.gz: src/opt/shortcutmkr/main.py <==
#!/usr/bin/python2.5
import sys
import os
from PyQt4 import QtGui,QtCore
from shortcutmkr import *
contact = ('')
num = ('')
class MyForm(QtGui.QMainWindow):
	def __init__(self, parent=None):
		#build parent user interface
		QtGui.QWidget.__init__(self, parent)
		self.ui = Ui_ShortcutMaker()
		self.ui.setupUi(self)
		self.initUI()
	def initUI(self):
        	self.setWindowTitle('Shortcut Maker')


		#connect buttons
		QtCore.QObject.connect(self.ui.pushButton, QtCore.SIGNAL('clicked()'), self.doCmd)
		QtCore.QObject.connect(self.ui.pushButton_2, QtCore.SIGNAL('clicked()'), self.doSms)
		QtCore.QObject.connect(self.ui.pushButton_3, QtCore.SIGNAL('clicked()'), self.doEmail)
		QtCore.QObject.connect(self.ui.pushButton_4, QtCore.SIGNAL('clicked()'), self.doPhone)
		QtCore.QObject.connect(self.ui.pushButton_5, QtCore.SIGNAL('clicked()'), self.doDeletecmd)
		QtCore.QObject.connect(self.ui.pushButton_6, QtCore.SIGNAL('clicked()'), self.doDeletesms)
		QtCore.QObject.connect(self.ui.pushButton_7, QtCore.SIGNAL('clicked()'), self.doDeleteemail)
		QtCore.QObject.connect(self.ui.pushButton_8, QtCore.SIGNAL('clicked()'), self.doDeletephone)
		
		
		#Create Sub's
	def doDeletesms(self): 
		contact = self.ui.lineEdit.text()
		os.remove('/usr/share/applications/hildon/sms'+contact+'.desktop')
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')
	
	def doDeleteemail(self):
		contact = self.ui.lineEdit.text()
		os.remove('/usr/share/applications/hildon/email'+contact+'.desktop')
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')

	def doDeletephone(self):
		contact = self.ui.lineEdit.text()
		os.remove('/usr/share/applications/hildon/phone'+contact+'.desktop')
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')

	def doSms(self):
		contact  = self.ui.lineEdit.text()
		num = self.ui.lineEdit_2.text()
		fsock = open('/usr/share/applications/hildon/sms'+ contact +'.desktop', 'w') 

		saveout = sys.stdout                                     
                            

		sys.stdout = fsock                                       

		print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=SMS to''', contact,'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","EnsureChannel","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"''',num,'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.Text"},0,""))'
Icon=general_sms''', 

		sys.stdout = saveout                                     

		fsock.close()
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')
	
	def doEmail(self):
		contact  = self.ui.lineEdit.text()
		num = self.ui.lineEdit_2.text()
		fsock2 = open('/usr/share/applications/hildon/email'+ contact +'.desktop', 'w') 

		saveout = sys.stdout                                     
                            

		sys.stdout = fsock2                                       

		print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=EMAIL to ''',contact,'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("com.nokia.modest","/com/nokia/modest", "com.nokia.modest","ComposeMail","ssssss", ("''',num,'''","","","","",""))'
Icon=general_email'''

		sys.stdout = saveout                                     

		fsock2.close()
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')

	def doPhone(self):
		contact  = self.ui.lineEdit.text()
		num = self.ui.lineEdit_2.text()
		fsock3 = open('/usr/share/applications/hildon/phone'+ contact +'.desktop', 'w') 

		saveout = sys.stdout                                     
                            

		sys.stdout = fsock3                                       

		print '''[Desktop Entry]
Encoding=UTF-8
Version=0.1
Type=Application
Name=Call ''',contact,'''
Exec=python -c 'import dbus; print dbus.Bus().call_blocking("org.freedesktop.Telepathy.AccountManager","/org/freedesktop/Telepathy/Account/ring/tel/ring", "com.nokia.Account.Interface.ChannelRequests","Create","a{sv}ts", ({"org.freedesktop.Telepathy.Channel.TargetHandleType":dbus.UInt32(1),"org.freedesktop.Telepathy.Channel.TargetID":"''',num,'''","org.freedesktop.Telepathy.Channel.ChannelType":"org.freedesktop.Telepathy.Channel.Type.StreamedMedia"},0,""))'
Icon=general_call'''

		sys.stdout = saveout                                     

		fsock3.close()
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')
		
	




	def doCmd(self):
		contact  = self.ui.lineEdit.text()
		num = self.ui.lineEdit_2.text()
		fsock = open('/usr/share/applications/hildon/cmd'+ contact +'.desktop', 'w') 

		saveout = sys.stdout                                     
                            

		sys.stdout = fsock                                       

		print '''[Desktop Entry]
Encoding=UTF-8
Name=''',contact,'''
Exec=osso-xterm "''',num,'''"
Icon=filemanager_file_loading
X-Osso-Type=application/x-executable
X-HildonDesk-ShowInToolbar=true
Type=Application
StartupNotify=true'''

		sys.stdout = saveout                                     

		fsock.close()
		self.ui.lineEdit.clear()
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')


	def doDeletecmd(self): 
		contact = self.ui.lineEdit.text()
		os.remove('/usr/share/applications/hildon/cmd'+contact+'.desktop')
		self.ui.lineEdit.clear()		
		self.ui.lineEdit_2.clear()
		contact = ('')
		num = ('')


if __name__ == "__main__":
	app = QtGui.QApplication(sys.argv)
	myapp = MyForm()
	myapp.show()
	sys.exit(app.exec_())
